@@ -1,6 +1,7 @@
 # pylint: disable=no-member, invalid-name, redefined-outer-name
 # pylint: disable=too-many-lines
 
+import importlib
 import os
 from collections import namedtuple
 from copy import deepcopy
@@ -21,6 +22,7 @@ from ... import (
     concat,
     convert_to_dataset,
     convert_to_inference_data,
+    from_datatree,
     from_dict,
     from_json,
     from_netcdf,
@@ -40,6 +42,7 @@ from ..helpers import (  # pylint: disable=unused-import
     draws,
     eight_schools_params,
     models,
+    running_on_ci,
 )
 
 
@@ -1294,10 +1297,11 @@ class TestDataNetCDF:
         os.remove(filepath)
         assert not os.path.exists(filepath)
 
+    @pytest.mark.parametrize("base_group", ["/", "test_group", "group/subgroup"])
     @pytest.mark.parametrize("groups_arg", [False, True])
     @pytest.mark.parametrize("compress", [True, False])
     @pytest.mark.parametrize("engine", ["h5netcdf", "netcdf4"])
-    def test_io_method(self, data, eight_schools_params, groups_arg, compress, engine):
+    def test_io_method(self, data, eight_schools_params, groups_arg, base_group, compress, engine):
         # create InferenceData and check it has been properly created
         inference_data = self.get_inference_data(  # pylint: disable=W0612
             data, eight_schools_params
@@ -1334,12 +1338,13 @@ class TestDataNetCDF:
             filepath,
             groups=("posterior", "observed_data") if groups_arg else None,
             compress=compress,
+            base_group=base_group,
         )
 
         # assert file has been saved correctly
         assert os.path.exists(filepath)
         assert os.path.getsize(filepath) > 0
-        inference_data2 = InferenceData.from_netcdf(filepath)
+        inference_data2 = InferenceData.from_netcdf(filepath, base_group=base_group)
         if groups_arg:  # if groups arg, update test dict to contain only saved groups
             test_dict = {
                 "posterior": ["eta", "theta", "mu", "tau"],
@@ -1381,6 +1386,20 @@ class TestJSON:
         assert not os.path.exists(filepath)
 
 
+@pytest.mark.skipif(
+    not (importlib.util.find_spec("datatree") or running_on_ci()),
+    reason="test requires xarray-datatree library",
+)
+class TestDataTree:
+    def test_datatree(self):
+        idata = load_arviz_data("centered_eight")
+        dt = idata.to_datatree()
+        idata_back = from_datatree(dt)
+        for group, ds in idata.items():
+            assert_identical(ds, idata_back[group])
+        assert all(group in dt.children for group in idata.groups())
+
+
 class TestConversions:
     def test_id_conversion_idempotent(self):
         stored = load_arviz_data("centered_eight")
