@@ -2,13 +2,13 @@
 """General utilities."""
 import functools
 import importlib
+import importlib.resources
 import re
 import warnings
 from functools import lru_cache
 
 import matplotlib.pyplot as plt
 import numpy as np
-import pkg_resources
 from numpy import newaxis
 
 from .rcparams import rcParams
@@ -174,6 +174,7 @@ class maybe_numba_fn:  # pylint: disable=invalid-name
     def __init__(self, function, **kwargs):
         """Wrap a function and save compilation keywords."""
         self.function = function
+        kwargs.setdefault("nopython", True)
         self.kwargs = kwargs
 
     @lazy_property
@@ -406,7 +407,7 @@ def _dot(x, y):
 
 @conditional_jit(cache=True, nopython=True)
 def _cov_1d(x):
-    x = x - x.mean(axis=0)
+    x = x - x.mean()
     ddof = x.shape[0] - 1
     return np.dot(x.T, x.conj()) / ddof
 
@@ -658,7 +659,9 @@ def _load_static_files():
 
     Clone from xarray.core.formatted_html_template.
     """
-    return [pkg_resources.resource_string("arviz", fname).decode("utf8") for fname in STATIC_FILES]
+    return [
+        importlib.resources.files("arviz").joinpath(fname).read_text() for fname in STATIC_FILES
+    ]
 
 
 class HtmlTemplate:
